@@ -16,6 +16,7 @@ class _Packager(Manager):
         self.ready = True
 
     def installed(self, pattern=None):
+        self._get_ready_()
         if pattern:
             for name, ver in self.do_installed():
                 if pattern in name:
@@ -23,16 +24,17 @@ class _Packager(Manager):
         else:
             yield from self.do_installed()
 
-    def available(self, pattern=None):
+    def installable(self, pattern=None):
         self._get_ready_()
         if pattern:
-            for name, ver in self.do_available():
+            for name, ver in self.do_installable():
                 if pattern in name.lower():
                     yield name, ver
         else:
-            yield from self.do_available()
+            yield from self.do_installable()
 
     def bigs(self):
+        self._get_ready_()
         info('\tbigs')
         for line in self.do_bigs():
             size, pkg = line.split()
@@ -42,32 +44,39 @@ class _Packager(Manager):
             yield f'{size:>7} {pkg}'
 
     def upgradable(self):
+        self._get_ready_()
         info('\tupgradable')
         yield from self.do_upgradable()
 
     def update(self):
+        self._get_ready_()
         info('\tupdate')
         self.do_update()
         for name, ver in self.upgradable():
             info(f'\t\t{name}')
 
     def upgrade(self):
+        self._get_ready_()
         info('\tupgrade')
         self.do_upgrade()
 
     def install(self, name, ver=None):
         if name in self.done: return
         self._get_ready_()
+        info('\t--> %s', name)
         self.done.add(name)
         pkg = self.pkgmap.get(name, name)
         self.do_install(pkg, ver)
 
     def remove(self, name):
+        self._get_ready_()
         info('\t<-- %s', name)
+        self.done.discard(name)
         pkg = self.pkgmap.get(name, name)
         self.do_remove(pkg)
 
     def cleanup(self):
+        self._get_ready_()
         info('\tcleanup')
         self.do_cleanup()
 
@@ -80,7 +89,7 @@ class _Packager(Manager):
     def do_remove(self, pkg): todo(self)
     def do_cleanup(self): todo(self)
     def do_installed(self): todo(self)
-    def do_available(self): todo(self)
+    def do_installable(self): todo(self)
 
 
 class SystemPackager(_Packager):
